pub fn run_singlethreaded_test<F, Fut, R>(test: F, options: TestOptions) -> RExpand description
Runs a test in an executor, potentially repeatedly and concurrently.
pub fn run_singlethreaded_test<F, Fut, R>(test: F, options: TestOptions) -> RRuns a test in an executor, potentially repeatedly and concurrently.