pub trait MultithreadedTestResult: Sized {
// Required methods
fn run<F: 'static + Sync + Fn(usize) -> Fut, Fut: 'static + Send + Future<Output = Self>>(
test: F,
threads: u8,
options: TestOptions,
cfg: EnvironmentConfig,
) -> Self;
fn is_ok(&self) -> bool;
}Expand description
Defines how to compose multiple test runs for a kind of test result in a multithreaded executor.
Required Methods
Sourcefn run<F: 'static + Sync + Fn(usize) -> Fut, Fut: 'static + Send + Future<Output = Self>>(
test: F,
threads: u8,
options: TestOptions,
cfg: EnvironmentConfig,
) -> Self
fn run<F: 'static + Sync + Fn(usize) -> Fut, Fut: 'static + Send + Future<Output = Self>>( test: F, threads: u8, options: TestOptions, cfg: EnvironmentConfig, ) -> Self
How to repeatedly run a test with this result in a multi threaded executor.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".