WakeupTime

Trait WakeupTime 

pub trait WakeupTime {
    // Required method
    fn into_timer(self) -> Timer ;
}
The time when a Timer should wakeup.

Required Methods

fn into_timer(self) -> Timer

Create a timer based on this time.

This is allowed to be inaccurate, but the inaccuracy must make the wakeup time later, never earlier.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WakeupTime for BootDuration

Available on Fuchsia only.
Source

impl WakeupTime for BootInstant

Source

impl WakeupTime for Duration

Available on Fuchsia only.
Source

impl WakeupTime for Instant

Source

impl WakeupTime for MonotonicInstant

Implementors

Source

impl WakeupTime for fuchsia_async::BootInstant

Source

impl WakeupTime for MonotonicDuration

Available on Fuchsia only.
Source

impl WakeupTime for fuchsia_async::MonotonicInstant